==> selenium-selenium-4.40.0.gh.tar.gz: selenium-selenium-4.40.0/java/test/org/openqa/selenium/support/ui/QuotesTest.java <==
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.openqa.selenium.support.ui;

import static org.assertj.core.api.Assertions.assertThat;
import static org.openqa.selenium.support.ui.Quotes.escape;

import org.junit.jupiter.api.Tag;
import org.junit.jupiter.api.Test;

@Tag("UnitTests")
class QuotesTest {
  @Test
  void shouldConvertAnUnquotedStringIntoOneWithQuotes() {
    assertThat(escape("foo")).isEqualTo("\"foo\"");
  }

  @Test
  void shouldConvertAStringWithATickIntoOneWithQuotes() {
    assertThat(escape("f'oo")).isEqualTo("\"f'oo\"");
  }

  @Test
  void shouldConvertAStringWithAQuotIntoOneWithTicks() {
    assertThat(escape("f\"oo")).isEqualTo("'f\"oo'");
  }

  @Test
  void shouldProvideConcatenatedStringsWhenStringToEscapeContainsTicksAndQuotes() {
    assertThat(escape("f\"o'o")).isEqualTo("concat(\"f\", '\"', \"o'o\")");
  }

  /**
   * Tests that Quotes.escape returns concatenated strings when the given string contains a tick and
   * and ends with a quote.
   */
  @Test
  void shouldProvideConcatenatedStringsWhenStringEndsWithQuote() {
    assertThat(escape("Bar \"Rock'n'Roll\""))
        .isEqualTo("concat(\"Bar \", '\"', \"Rock'n'Roll\", '\"')");
  }
}

==> selenium-selenium-4.41.0.gh.tar.gz: selenium-selenium-4.41.0/java/test/org/openqa/selenium/support/ui/QuotesTest.java <==
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.openqa.selenium.support.ui;

import static org.assertj.core.api.Assertions.assertThat;
import static org.openqa.selenium.support.ui.Quotes.escape;

import org.junit.jupiter.api.Tag;
import org.junit.jupiter.api.Test;

@Tag("UnitTests")
class QuotesTest {
  @Test
  void shouldConvertAnUnquotedStringIntoOneWithQuotes() {
    assertThat(escape("foo")).isEqualTo("\"foo\"");
  }

  @Test
  void shouldConvertAStringWithATickIntoOneWithQuotes() {
    assertThat(escape("f'oo")).isEqualTo("\"f'oo\"");
  }

  @Test
  void shouldConvertAStringWithAQuotIntoOneWithTicks() {
    assertThat(escape("f\"oo")).isEqualTo("'f\"oo'");
  }

  @Test
  void shouldProvideConcatenatedStringsWhenStringToEscapeContainsTicksAndQuotes() {
    assertThat(escape("f\"o'o")).isEqualTo("concat(\"f\", '\"', \"o'o\")");
  }

  /**
   * Tests that {@link Quotes#escape(String)} returns concatenated strings when the given string
   * contains a tick and ends with a quote.
   */
  @Test
  void shouldProvideConcatenatedStringsWhenStringEndsWithQuote() {
    assertThat(escape("Bar \"Rock'n'Roll\""))
        .isEqualTo("concat(\"Bar \", '\"', \"Rock'n'Roll\", '\"')");
  }
}
